@@ -5,20 +5,20 @@ from metering.client import Client
 __version__ = VERSION
 
 """Settings."""
-user_name = None
-password = None
+user_name = 'demo'
+password = 'chengeme'
 host = None
 on_error = None
 debug = False
 send = True
-sync_mode = False
+wait = False
 
 default_client = None
 
 
-def track(*args, **kwargs):
-    """Send a track call."""
-    _proxy('track', *args, **kwargs)
+def meter(*args, **kwargs):
+    """Send a meter call."""
+    _proxy('meter', *args, **kwargs)
 
 
 
@@ -43,9 +43,9 @@ def _proxy(method, *args, **kwargs):
     """Create an analytics client if one doesn't exist and send to it."""
     global default_client
     if not default_client:
-        default_client = Client(user_name,password, host=host, debug=debug,
+        default_client = Client(user_name,password, debug=debug,
                                 on_error=on_error, send=send,
-                                sync_mode=sync_mode)
+                                wait=wait)
 
     fn = getattr(default_client, method)
     fn(*args, **kwargs)
